Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IQ.

Actions, resources, and condition keys for AWS IQ - Service Authorization Reference

# Actions, resources, and condition keys for AWS IQ

AWS IQ (service prefix: `iq` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS IQ
- Resource types defined by AWS IQ
- Condition keys for AWS IQ

## Actions defined by AWS IQ

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptCall | Grants permission to accept an incoming voice/video call | Write | call* |  |
ApprovePaymentRequest | Grants permission to approve a payment request | Write | paymentRequest* |  |
ApproveProposal | Grants permission to approve a proposal | Write | proposal* |  |
ArchiveConversation | Grants permission to archive a conversation | Write | conversation* |  |
CompleteProposal | Grants permission to complete a proposal | Write | proposal* |  |
CreateConversation | Grants permission to respond to a request or send a direct message to initiate a conversation | Write |  |  |
CreateExpert | Grants permission to create an expert profile | Write |  |  |
CreateListing | Grants permission to create a listing | Write |  |  |
CreateMilestoneProposal | Grants permission to create a milestone proposal | Write |  |  |
CreatePaymentRequest | Grants permission to create a payment request | Write |  |  |
CreateProject | Grants permission to submit new requests | Write |  |  |
CreateRequest | Grants permission to submit new requests | Write |  |  |
CreateScheduledProposal | Grants permission to create a scheduled proposal | Write |  |  |
CreateSeller | Grants permission to create a seller profile | Write |  |  |
CreateUpfrontProposal | Grants permission to create an upfront proposal | Write |  |  |
DeclineCall | Grants permission to decline an incoming voice/video call | Write | call* |  |
DeleteAttachment | Grants permission to delete an existing attachment | Write | attachment* |  |
DisableIndividualPublicProfile | Grants permission to disable individual public profile page | Write | expert* |  |
DownloadAttachment | Grants permission to download existing attachment | Read | attachment* |  |
EnableIndividualPublicProfile | Grants permission to enable individual public profile page | Write | expert* |  |
EndCall | Grants permission to end a voice/video call | Write | call* |  |
GetBuyer | Grants permission to read buyer information | Read | buyer* |  |
GetCall | Grants permission to read details of a voice/video call | Read | call* |  |
GetChatInfo | Grants permission to read the chat environment details about a conversation | Read | conversation* |  |
GetChatMessages | Grants permission to read chat messages in a conversation | Read | conversation* |  |
GetChatToken | Grants permission to request a websocket token for the conversation notifications | Read | token* |  |
GetCompanyChatMessages | Grants permission to read chat messages in a company conversation | Read | conversation* |  |
GetCompanyProfile | Grants permission to read a company profile | Read | company* |  |
GetConversation | Grants permission to read details of a conversation | Read | conversation* |  |
GetExpert | Grants permission to read expert information | Read | expert* |  |
GetListing | Grants permission to read a listing | Read | listing* |  |
GetMarketplaceSeller | Grants permission to read a seller profile information | Read | seller* |  |
GetPaymentRequest | Grants permission to read a payment request | Read | paymentRequest* |  |
GetProposal | Grants permission to read a proposal | Read | proposal* |  |
GetRequest | Grants permission to get a created request | Read | request* |  |
GetReview | Grants permission to read a review for an expert | Read | seller* |  |
HideRequest | Grants permission to hide a request | Write | request* |  |
InitiateCall | Grants permission to start a voice/video call | Write |  |  |
LinkAwsCertification | Grants permission to link an AWS certification to individual profile | Write | expert* |  |
ListAttachments | Grants permission to list existing attachments | List | attachment* |  |
ListConversations | Grants permission to list existing conversations | Read | conversation* |  |
ListExpertAccessLogs | Grants permission to list access logs of expert activity | Read | permission* |  |
ListListings | Grants permission to list listings | Read | listing* |  |
ListPaymentRequests | Grants permission to list payment requests | Read | paymentRequest |  |
paymentSchedule |  |
ListProposals | Grants permission to list proposals | Read | proposal* |  |
ListRequests | Grants permission to list requests that are created | Read | request* |  |
ListReviews | Grants permission to list reviews for an expert | Read | seller* |  |
MarkChatMessageRead | Grants permission to mark a message as read in a conversation | Write | conversation* |  |
RejectPaymentRequest | Grants permission to reject a payment request | Write | paymentRequest* |  |
RejectProposal | Grants permission to reject a proposal | Write | proposal* |  |
SendCompanyChatMessage | Grants permission to send a message in a conversation as a company | Write | conversation* |  |
SendIndividualChatMessage | Grants permission to send a message in a conversation as an individual | Write | conversation* |  |
UnarchiveConversation | Grants permission to unarchive a conversation | Write | conversation* |  |
UnlinkAwsCertification | Grants permission to unlink an AWS certification from individual profile | Write | expert* |  |
UpdateCompanyProfile | Grants permission to update a company profile | Write | company* |  |
UpdateConversationMembers | Grants permission to add more participants into a conversation | Write | conversation* |  |
UpdateExpert | Grants permission to update an expert information | Write | expert* |  |
UpdateListing | Grants permission to update a listing | Write | listing* |  |
UpdateRequest | Grants permission to update a request | Write | request* |  |
UploadAttachment | Grants permission to upload an attachment | Write |  |  |
WithdrawPaymentRequest | Grants permission to withdraw a payment request | Write | paymentRequest* |  |
WithdrawProposal | Grants permission to withdraw a proposal | Write | proposal* |  |
WriteReview | Grants permission to write a review for an expert | Write | seller* |  |

## Resource types defined by AWS IQ

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
conversation | `arn:$ { Partition}:iq:$ { Region}::conversation/$ { ConversationId}` |
buyer | `arn:$ { Partition}:iq:$ { Region}::buyer/$ { BuyerId}` |
expert | `arn:$ { Partition}:iq:$ { Region}::expert/$ { ExpertId}` |
call | `arn:$ { Partition}:iq:$ { Region}::call/$ { CallId}` |
token | `arn:$ { Partition}:iq:$ { Region}::token/$ { TokenId}` |
proposal | `arn:$ { Partition}:iq:$ { Region}::proposal/$ { ConversationId}/$ { ProposalId}` |
paymentRequest | `arn:$ { Partition}:iq:$ { Region}::paymentRequest/$ { ConversationId}/$ { ProposalId}/$ { PaymentRequestId}` |
paymentSchedule | `arn:$ { Partition}:iq:$ { Region}::paymentSchedule/$ { ConversationId}/$ { ProposalId}/$ { VersionId}` |
seller | `arn:$ { Partition}:iq:$ { Region}::seller/$ { SellerAwsAccountId}` |
company | `arn:$ { Partition}:iq:$ { Region}::company/$ { CompanyId}` |
request | `arn:$ { Partition}:iq:$ { Region}::request/$ { RequestId}` |
listing | `arn:$ { Partition}:iq:$ { Region}::listing/$ { ListingId}` |
attachment | `arn:$ { Partition}:iq:$ { Region}::attachment/$ { AttachmentId}` |
permission | `arn:$ { Partition}:iq-permission:$ { Region}::permission/$ { PermissionRequestId}` |

## Condition keys for AWS IQ

IQ has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.